@@ -426,7 +426,11 @@ Boolean ChangeLayerName(LayerTypePtr Layer, char *Name)
  */
 static void *ChangeElementSquare(ElementTypePtr Element)
 {
-	return(ChangePinSquare(Element, &Element->Pin[0]));
+	if (Element->PinN > 0)
+		return(ChangePinSquare(Element, &Element->Pin[0]));
+	else if (Element->PadN > 0)
+		return(ChangePadSquare(Element, &Element->Pad[0]));
+	return(NULL);
 }
 
 /* ---------------------------------------------------------------------------
