@@ -132,17 +132,22 @@ static Boolean SearchPadByPosition(ElementTypePtr *Element, PadTypePtr *Pad,
 					 * global.h for details
 					 */
 				if (TEST_FLAG(SQUAREFLAG, pad))
-					if (IsPointInSquarePad(PosX, PosY, 0, pad))
 				{
+					if (IsPointInSquarePad(PosX, PosY, 0, pad))
+					{
 						*Element = element;
 						*Pad = *Dummy = pad;
 						return(True);
 					}
-				else if (IsPointOnLine(PosX, PosY, 0, (LineTypePtr) pad))
+				}
+				else
 				{
-					*Element = element;
-					*Pad = *Dummy = pad;
-					return(True);
+					if (IsPointOnLine(PosX, PosY, 0, (LineTypePtr) pad))
+					{
+						*Element = element;
+						*Pad = *Dummy = pad;
+						return(True);
+					}
 				}
 			}
 		);
